"""
Provides systembridgemodels version information.
"""

# This file is auto-generated! Do not edit!
# Use `python -m incremental.update systembridgemodels` to change this file.

from incremental import Version

__version__ = Version("systembridgemodels", 4, 2, 2)
__all__ = ["__version__"]
